@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -245,7 +245,7 @@ class AutoMlAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a dataset.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -361,7 +361,7 @@ class AutoMlAsyncClient:
     ) -> dataset.Dataset:
         r"""Gets a dataset.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -463,7 +463,7 @@ class AutoMlAsyncClient:
     ) -> pagers.ListDatasetsAsyncPager:
         r"""Lists datasets in a project.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -574,7 +574,7 @@ class AutoMlAsyncClient:
     ) -> gca_dataset.Dataset:
         r"""Updates a dataset.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -686,7 +686,7 @@ class AutoMlAsyncClient:
         [metadata][google.longrunning.Operation.metadata] field.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -822,7 +822,7 @@ class AutoMlAsyncClient:
            field when it completes.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -957,7 +957,7 @@ class AutoMlAsyncClient:
         completes.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -1085,7 +1085,7 @@ class AutoMlAsyncClient:
     ) -> annotation_spec.AnnotationSpec:
         r"""Gets an annotation spec.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -1189,7 +1189,7 @@ class AutoMlAsyncClient:
         each annotation spec.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -1302,7 +1302,7 @@ class AutoMlAsyncClient:
     ) -> model.Model:
         r"""Gets a model.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -1400,7 +1400,7 @@ class AutoMlAsyncClient:
     ) -> pagers.ListModelsAsyncPager:
         r"""Lists models.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -1514,7 +1514,7 @@ class AutoMlAsyncClient:
         [metadata][google.longrunning.Operation.metadata] field.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -1640,7 +1640,7 @@ class AutoMlAsyncClient:
     ) -> gca_model.Model:
         r"""Updates a model.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -1754,7 +1754,7 @@ class AutoMlAsyncClient:
         completes.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -1878,7 +1878,7 @@ class AutoMlAsyncClient:
         completes.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -2002,7 +2002,7 @@ class AutoMlAsyncClient:
         completes.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -2132,7 +2132,7 @@ class AutoMlAsyncClient:
     ) -> model_evaluation.ModelEvaluation:
         r"""Gets a model evaluation.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -2231,7 +2231,7 @@ class AutoMlAsyncClient:
     ) -> pagers.ListModelEvaluationsAsyncPager:
         r"""Lists model evaluations.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
