@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -261,7 +261,7 @@ class PredictionServiceAsyncClient:
            up to 5MB. Not available for FORECASTING ``prediction_type``.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -426,7 +426,7 @@ class PredictionServiceAsyncClient:
         -  AutoML Tables
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
