@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -460,8 +460,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
            up to 5MB. Not available for FORECASTING ``prediction_type``.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
@@ -625,8 +624,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         -  AutoML Tables
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1
 
