@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -444,8 +444,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
            UTF-8 encoded.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1beta1
 
@@ -599,8 +598,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         -  Tables
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import automl_v1beta1
 
